---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: feature-request
assignees: ''

---

Pre-Request Checklist
---------------------

- [ ] I checked to make sure that this feature has not already been requested.

Issue Description
-----------------

Give a detailed description of the new feature, and what problem it is trying to solve.

If this is a proposal to change an existing feature, also outline the current
implementation and its drawbacks.

Thanks for helping us improve Mitiq! 🙂

Proposed Solution
-----------------

Let us know what you'd like to see happen, and be sure to mention
any alternatives that you've considered.


Additional References
---------------------

If applicable, provide some references that will help us better understand the request.
